==> ZenTaoPMS.16.5.php7.1.zip: zentaopms/extension/max/cm/lang/zh-cn.php <==
<?php
$lang->cm->common        = '项目配置';
$lang->cm->delete        = '删除基线';
$lang->cm->edit          = '编辑基线';
$lang->cm->browse        = '基线列表';
$lang->cm->report        = '配管报告';
$lang->cm->create        = '打基线';
$lang->cm->view          = '基线详情';
$lang->cm->object        = '配置项名称';
$lang->cm->title         = '配置项标识';
$lang->cm->from          = '评审版本';
$lang->cm->version       = '版本号';
$lang->cm->createdBy     = '由谁创建';
$lang->cm->createdDate   = '创建时间';
$lang->cm->noData        = '暂时没有基线,';
$lang->cm->confirmDelete = '删除该基线会同步删除基线状态报告中基线？';
$lang->cm->basicInfo     = '基本信息';

$lang->cm->baselineReport = '基线发布报告';
$lang->cm->projectID      = '项目编号:';
$lang->cm->release        = '发布形式:';
$lang->cm->approver       = '批准人:';
$lang->cm->projectName    = '项目名称:';
$lang->cm->compiling      = '编制人:';
$lang->cm->changeDesc     = '基线发布与变更描述';
$lang->cm->baselineID     = '序号';
$lang->cm->baselineTitle  = '基线项';
$lang->cm->reportRersion  = '版本号';
$lang->cm->releaseDate    = '发布时间';
$lang->cm->authorized     = '批准人员';
$lang->cm->publisher      = '发布人';
$lang->cm->baselineItem   = '基线';
$lang->cm->configItemName = '配置项名称';
$lang->cm->configIdentify = '配置标识';
$lang->cm->currentVersion = '当前版本';
$lang->cm->configAdmin    = '配置管理员';
$lang->cm->solutionMan    = '解决人';
$lang->cm->confManagement = '配置管理';
$lang->cm->personnelQA    = 'QA人员';
$lang->cm->issueID        = '问题ID';
$lang->cm->issueDesc      = '问题描述';
$lang->cm->baselineAudit  = '发现问题的基线审计名称';
$lang->cm->discoveryDate  = '发现时间';
$lang->cm->personLiable   = '责任人';
$lang->cm->proposedScheme = '建议解决方案';
$lang->cm->proposedDate   = '建议解决时间';
$lang->cm->solutionResult = '解决方法及结果';
$lang->cm->resolvingDate  = '解决时间';
$lang->cm->resolvingBy    = '解决人';
$lang->cm->currentState   = '当前状态';
$lang->cm->resultQA       = 'QA检查结果';

$lang->cm->auditItem['PP']     = 'plan';
$lang->cm->auditItem['SRS']    = 'story';
$lang->cm->auditItem['URS']    = 'story';
$lang->cm->auditItem['DDS']    = 'story';
$lang->cm->auditItem['HLDS']   = 'design';
$lang->cm->auditItem['ITTC']   = 'test';
$lang->cm->auditItem['ITP']    = 'test';
$lang->cm->auditItem['STP']    = 'test';
$lang->cm->auditItem['STTC']   = 'test';
$lang->cm->auditItem['manual'] = 'UM';
$lang->cm->auditItem['Code']   = 'project';
$lang->cm->auditItem['QAP']    = 'quality';
$lang->cm->auditItem['CMP']    = 'config';

$lang->cm->plan    = '计划基线项';
$lang->cm->story   = '需求基线项';
$lang->cm->design  = '设计基线项';
$lang->cm->test    = '测试基线项';
$lang->cm->manual  = '手册基线项';
$lang->cm->project = '程序基线项';
$lang->cm->quality = '质量基线项';
$lang->cm->config  = '配置基线项';
$lang->cm->custom  = '自定义基线项';

==> ZenTaoPMS.17.5.php5.4_5.6.zip: zentaopms/extension/max/cm/lang/zh-cn.php <==
<?php
$lang->cm->common        = '项目配置';
$lang->cm->delete        = '删除基线';
$lang->cm->edit          = '编辑基线';
$lang->cm->browse        = '基线列表';
$lang->cm->report        = '配管报告';
$lang->cm->create        = '打基线';
$lang->cm->view          = '基线详情';
$lang->cm->object        = '配置项名称';
$lang->cm->title         = '配置项标识';
$lang->cm->from          = '评审版本';
$lang->cm->version       = '版本号';
$lang->cm->createdBy     = '由谁创建';
$lang->cm->createdDate   = '创建时间';
$lang->cm->noData        = '暂时没有基线,';
$lang->cm->confirmDelete = '删除该基线会同步删除基线状态报告中基线？';
$lang->cm->basicInfo     = '基本信息';

$lang->cm->baselineReport = '基线发布报告';
$lang->cm->projectID      = '项目编号:';
$lang->cm->release        = '发布形式:';
$lang->cm->approver       = '批准人:';
$lang->cm->projectName    = '项目名称:';
$lang->cm->compiling      = '编制人:';
$lang->cm->changeDesc     = '基线发布与变更描述';
$lang->cm->baselineID     = '序号';
$lang->cm->baselineTitle  = '基线项';
$lang->cm->reportRersion  = '版本号';
$lang->cm->releaseDate    = '发布时间';
$lang->cm->authorized     = '批准人员';
$lang->cm->publisher      = '发布人';
$lang->cm->baselineItem   = '基线';
$lang->cm->configItemName = '配置项名称';
$lang->cm->configIdentify = '配置标识';
$lang->cm->currentVersion = '当前版本';
$lang->cm->configAdmin    = '配置管理员';
$lang->cm->solutionMan    = '解决人';
$lang->cm->confManagement = '配置管理';
$lang->cm->personnelQA    = 'QA人员';
$lang->cm->issueID        = '问题ID';
$lang->cm->issueDesc      = '问题描述';
$lang->cm->baselineAudit  = '发现问题的基线审计名称';
$lang->cm->discoveryDate  = '发现时间';
$lang->cm->personLiable   = '责任人';
$lang->cm->proposedScheme = '建议解决方案';
$lang->cm->proposedDate   = '建议解决时间';
$lang->cm->solutionResult = '解决方案';
$lang->cm->resolvingDate  = '解决时间';
$lang->cm->resolvingBy    = '解决人';
$lang->cm->currentState   = '当前状态';
$lang->cm->resultQA       = 'QA检查结果';

$lang->cm->auditItem['PP']     = 'plan';
$lang->cm->auditItem['SRS']    = 'story';
$lang->cm->auditItem['URS']    = 'story';
$lang->cm->auditItem['DDS']    = 'story';
$lang->cm->auditItem['HLDS']   = 'design';
$lang->cm->auditItem['ITTC']   = 'test';
$lang->cm->auditItem['ITP']    = 'test';
$lang->cm->auditItem['STP']    = 'test';
$lang->cm->auditItem['STTC']   = 'test';
$lang->cm->auditItem['manual'] = 'UM';
$lang->cm->auditItem['Code']   = 'project';
$lang->cm->auditItem['QAP']    = 'quality';
$lang->cm->auditItem['CMP']    = 'config';

$lang->cm->plan    = '计划基线项';
$lang->cm->story   = '需求基线项';
$lang->cm->design  = '设计基线项';
$lang->cm->test    = '测试基线项';
$lang->cm->manual  = '手册基线项';
$lang->cm->project = '程序基线项';
$lang->cm->quality = '质量基线项';
$lang->cm->config  = '配置基线项';
$lang->cm->custom  = '自定义基线项';
